@@ -31,20 +31,26 @@ func (p *TemplateProvider) AddMetadata(metadata *schema.ProjectMetadata) {
 	// no op
 }
 
-func (p *TemplateProvider) LoadResources(project *schema.Project, usage map[string]*schema.UsageData) error {
+func (p *TemplateProvider) LoadResources(usage map[string]*schema.UsageData) ([]*schema.Project, error) {
 	template, err := goformation.Open(p.Path)
 	if err != nil {
-		return errors.Wrap(err, "Error reading Cloudformation template file")
+		return []*schema.Project{}, errors.Wrap(err, "Error reading Cloudformation template file")
 	}
 
+	metadata := config.DetectProjectMetadata(p.ctx.ProjectConfig.Path)
+	metadata.Type = p.Type()
+	p.AddMetadata(metadata)
+	name := schema.GenerateProjectName(metadata, p.ctx.RunContext.Config.EnableDashboard)
+
+	project := schema.NewProject(name, metadata)
 	parser := NewParser(p.ctx)
 	pastResources, resources, err := parser.parseTemplate(template, usage)
 	if err != nil {
-		return errors.Wrap(err, "Error parsing Cloudformation template file")
+		return []*schema.Project{project}, errors.Wrap(err, "Error parsing Cloudformation template file")
 	}
 
 	project.PastResources = pastResources
 	project.Resources = resources
 
-	return nil
+	return []*schema.Project{project}, nil
 }
