@@ -4,6 +4,7 @@ import (
 	"sort"
 
 	"github.com/shopspring/decimal"
+	log "github.com/sirupsen/logrus"
 )
 
 var HourToMonthUnitMultiplier = decimal.NewFromInt(730)
@@ -67,6 +68,9 @@ func (r *Resource) CalculateCosts() {
 		r.HourlyCost = &h
 		r.MonthlyCost = &m
 	}
+	if r.NoPrice {
+		log.Debugf("Skipping free resource %s", r.Name)
+	}
 }
 
 func (r *Resource) FlattenedSubResources() []*Resource {
